> Docs are a work in process.

1. Install the docs dependencies

```bash
uv sync --extra docs
```

2. Run the build

```bash
just docs
```

3. Open `built_docs/html/index.html` in your browser, however you please